FrUnion class

平铺状态, 可通过命名叠加来区分层级

Constructors

FrUnion.build({required Map<String, FrUnionModel> initials, required Map<String, FrUnionModel> value})
const
FrUnion.ofModel(Set<FrUnionModel> models)
factory
FrUnion.ofTaggedModel(Set<TaggedUnionModel> tagModels)
use '' for default tag
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
initials Map<String, FrUnionModel>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Map<String, FrUnionModel>
final

Methods

copyWith(Map<String, FrUnionModel> value) FrUnion
modelValue<M>(String tag) → M
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

modelKey<M>({String tag = ''}) String
modelKeyByValue<M>({required String tag, required M value}) String
of<T extends Object>(Set<T> models) FrUnion
support FrUnion.ofModel & FrUnion.ofTaggedModel