LogExtra class
tp
null: not print log extra info (dev tips, stack, ...)
inner : last FlowR method
- This is where you call the ::logger
self : (dft) last your CustomViewModel(or other class) method
- This is where you call the ::update
outer : invoke FlowR method at log.name
- This is where you call the method that contains the ::update method
all : for dev, print all stack frame info
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited