buildWhen property

ValueStreamBuilderCondition<T>? buildWhen
final

Takes the previous value and the current value and is responsible for returning a bool which determines whether or not to trigger builder with the current value.

Implementation

final ValueStreamBuilderCondition<T>? buildWhen;