builder property

ValueStreamWidgetBuilder<T> builder
final

The builder function which will be invoked on each widget build. The builder takes the BuildContext and current value and must return a widget. This is analogous to the builder function in StreamBuilder.

Implementation

final ValueStreamWidgetBuilder<T> builder;