ValueStreamController<T> class

Small test/support controller with ValueStream semantics.

Inheritance
Implemented types
Available extensions

Constructors

ValueStreamController({void onListen()?})
ValueStreamController.seeded(T value, {void onListen()?})

Properties

error Object
no setteroverride
errorOrNull Object?
no setteroverride
first Future<T>
The first element of this stream.
no setterinherited
hasError bool
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
no setteroverride
isBroadcast bool
Whether this stream is a broadcast stream.
no setteroverride
isEmpty Future<bool>
Whether this stream contains any elements.
no setterinherited
last Future<T>
The last element of this stream.
no setterinherited
length Future<int>
The number of elements in this stream.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single Future<T>
The single element of this stream.
no setterinherited
stackTrace StackTrace?
no setteroverride
stream ValueStream<T>
no setter
value → T
no setteroverride
valueOrNull → T?
no setteroverride

Methods

add(T value) → void
addError(Object error, [StackTrace? stackTrace]) → void
any(bool test(T element)) Future<bool>
Checks whether test accepts any element provided by this stream.
inherited
asBroadcastStream({void onListen(StreamSubscription<T> subscription)?, void onCancel(StreamSubscription<T> subscription)?}) Stream<T>
Returns a multi-subscription stream that produces the same events as this.
inherited
asyncExpand<E>(Stream<E>? convert(T event)) Stream<E>
Transforms each element into a sequence of asynchronous events.
inherited
asyncMap<E>(FutureOr<E> convert(T event)) Stream<E>
Creates a new stream with each data event of this stream asynchronously mapped to a new event.
inherited
cast<R>() Stream<R>
Adapt this stream to be a Stream<R>.
inherited
close() Future<void>
contains(Object? needle) Future<bool>
Returns whether needle occurs in the elements provided by this stream.
inherited
debounce(Stream<void> window(T event)) Stream<T>

Available on Stream<T>, provided by the DebounceExtensions extension

debounceTime(Duration duration) Stream<T>

Available on Stream<T>, provided by the DebounceExtensions extension

delay(Duration duration) Stream<T>

Available on Stream<T>, provided by the DelayExtension extension

distinct([bool equals(T previous, T next)?]) Stream<T>
Skips data events if they are equal to the previous data event.
inherited
distinctBy<S>([S field(T event)?]) Stream<T>

Available on Stream<T>, provided by the DistinctByX extension

use for FlowR.stream or flowr/FrViewModel.stream
distinctBy<S>([S field(T event)?]) ValueStream<T>

Available on ValueStream<T>, provided by the DistinctByValueX extension

distinctBy for ValueStream
distinctUnique({bool equals(T previous, T next)?}) Stream<T>

Available on Stream<T>, provided by the DistinctUniqueExtension extension

distinctWith<S>(S field(T event)) Stream<S>

Available on Stream<T>, provided by the DistinctWithX extension

use for FlowR.stream or flowr.FrViewModel.stream
distinctWith<S>(S field(T event)) ValueStream<S>

Available on ValueStream<T>, provided by the DistinctWithValueX extension

distinctBy for ValueStream
doOnData(void onData(T event)) Stream<T>

Available on Stream<T>, provided by the DoExtensions extension

doOnDone(void onDone()) Stream<T>

Available on Stream<T>, provided by the DoExtensions extension

doOnError(void onError(Object error, StackTrace stackTrace)) Stream<T>

Available on Stream<T>, provided by the DoExtensions extension

drain<E>([E? futureValue]) Future<E>
Discards all data on this stream, but signals when it is done or an error occurred.
inherited
elementAt(int index) Future<T>
Returns the value of the indexth data event of this stream.
inherited
every(bool test(T element)) Future<bool>
Checks whether test accepts all elements provided by this stream.
inherited
expand<S>(Iterable<S> convert(T element)) Stream<S>
Transforms each element of this stream into a sequence of elements.
inherited
firstWhere(bool test(T element), {T orElse()?}) Future<T>
Finds the first element of this stream matching test.
inherited
fold<S>(S initialValue, S combine(S previous, T element)) Future<S>
Combines a sequence of values by repeatedly applying combine.
inherited
forEach(void action(T element)) Future<void>
Executes action on each element of this stream.
inherited
handleError(Function onError, {bool test(dynamic error)?}) Stream<T>
Creates a wrapper Stream that intercepts some errors from this stream.
inherited
join([String separator = ""]) Future<String>
Combines the string representation of elements into a single string.
inherited
lastWhere(bool test(T element), {T orElse()?}) Future<T>
Finds the last element in this stream matching test.
inherited
listen(void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError}) StreamSubscription<T>
Adds a subscription to this stream.
override
map<S>(S convert(T event)) Stream<S>
Transforms each element of this stream into a new stream event.
inherited
mapValue<U>(U mapper(T value)) ValueStream<U>

Available on ValueStream<T>, provided by the MapValueX extension

map for ValueStream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pipe(StreamConsumer<T> streamConsumer) Future
Pipes the events of this stream into streamConsumer.
inherited
publish() Stream<T>

Available on Stream<T>, provided by the ConnectableStreamExtensions extension

publishValueSeeded(T seedValue) ValueStream<T>

Available on Stream<T>, provided by the ConnectableStreamExtensions extension

reduce(T combine(T previous, T element)) Future<T>
Combines a sequence of values by repeatedly applying combine.
inherited
shareValueSeeded(T seedValue) ValueStream<T>

Available on Stream<T>, provided by the ConnectableStreamExtensions extension

singleWhere(bool test(T element), {T orElse()?}) Future<T>
Finds the single element in this stream matching test.
inherited
skip(int count) Stream<T>
Skips the first count data events from this stream.
inherited
skipWhile(bool test(T element)) Stream<T>
Skip data events from this stream while they are matched by test.
inherited
switchMap<S>(Stream<S> mapper(T value)) Stream<S>

Available on Stream<T>, provided by the SwitchMapExtension extension

take(int count) Stream<T>
Provides at most the first count data events of this stream.
inherited
takeWhile(bool test(T element)) Stream<T>
Forwards data events while test is successful.
inherited
timeout(Duration timeLimit, {void onTimeout(EventSink<T> sink)?}) Stream<T>
Creates a new stream with the same events as this stream.
inherited
toList() Future<List<T>>
Collects all elements of this stream in a List.
inherited
toSet() Future<Set<T>>
Collects the data of this stream in a Set.
inherited
toString() String
A string representation of this object.
inherited
transform<S>(StreamTransformer<T, S> streamTransformer) Stream<S>
Applies streamTransformer to this stream.
inherited
where(bool test(T event)) Stream<T>
Creates a new stream from this stream that discards some elements.
inherited
whereNotNull() Stream<T>

Available on Stream<T?>, provided by the WhereNotNullExtension extension

whereValue(bool test(T value)) ValueStream<T>

Available on ValueStream<T>, provided by the WhereValueX extension

where for ValueStream

Operators

operator ==(Object other) bool
The equality operator.
inherited