ValueStreamWidgetBuilder<T> typedef

ValueStreamWidgetBuilder<T> = Widget Function(BuildContext context, T value, Widget? child)

Signature for the builder function which takes the BuildContext and the current value and is responsible for returning a widget which is to be rendered. This is analogous to the builder function in StreamBuilder.

Implementation

typedef ValueStreamWidgetBuilder<T> =
    Widget Function(BuildContext context, T value, Widget? child);