a simple filter function to be used inside SimpleEnvironmentFilter
filter for whether to register for the given set of environments
clients can extend this class to maker
their own environmentFilters
Very simple and easy to use service locator
You register your object creation factory or an instance of an object with registerFactory,
registerSingleton or registerLazySingleton
And retrieve the desired object using get or call your locator as function as its a
callable class
Additionally GetIt offers asynchronous creation functions as well as functions to synchronize
the async initialization of multiple Singletons
tp
null: not print log extra info (dev tips, stack, ...)
inner : last FlowR method
- This is where you call the ::logger
self : (dft) last your CustomViewModel(or other class) method
- This is where you call the ::update
outer : invoke FlowR method at log.name
- This is where you call the method that contains the ::update method
all : for dev, print all stack frame info
Extends the Stream with the ability to convert one stream into a new Stream
whenever the source emits an item. Every time a new Stream is created, the
previous Stream is discarded.
Extends the Stream class with the ability to convert the source Stream
to a Stream which emits all the non-null elements
of this Stream, in their original emission order.