FrConfig class
FlowR global config
void main() {
FrConfig.initialize(
frUnion: FrUnion.of({CounterM(0)}),
);
runApp(const MyApp());
}
Properties
- di → GetIt
-
final
- emitEqualValues → bool
-
no setter
- frUnion → FrUnion?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logLevel → Level
-
no setter
- printer → FrLogRecordPrinter
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- I → FrConfig
-
Last applied config.
no setter
- instanceOrNull → FrConfig?
-
no setter
- isInitialized → bool
-
no setter
Static Methods
-
initialize(
{Level logLevel = Level.INFO, FrLogRecordPrinter printer = LoggableMx.devLogRecordPrinter, FrUnion? frUnion, GetIt? di, bool emitEqualValues = false}) → FrConfig - Creates and applies the global FlowR configuration.
-
reset(
{GetIt? di, bool unregisterFrUnion = false}) → Future< void> - Clears FlowR's global log listener and optionally unregisters FrUnionViewModel.