LogExtra class

tp null: not print log extra info (dev tips, stack, ...) inner : last FlowR method - This is where you call the ::logger self : (dft) last your CustomViewModel(or other class) method - This is where you call the ::update outer : invoke FlowR method at log.name - This is where you call the method that contains the ::update method all : for dev, print all stack frame info

Constructors

LogExtra(String? tp, {Object? raw})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
raw Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tp String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const LogExtra
inner → const LogExtra
outer → const LogExtra
self → const LogExtra