ValueStreamWidgetListener<T> typedef
ValueStreamWidgetListener<T> =
void Function(BuildContext context, T previous, T current)
ValueStream listener adapted for FlowR's bloc-backed ValueStream contract.
Signature for the listener function which takes the BuildContext along
with the previous and current value and is responsible for
executing in response to value changes.
Implementation
/// Signature for the `listener` function which takes the `BuildContext` along
/// with the previous and current `value` and is responsible for
/// executing in response to `value` changes.
typedef ValueStreamWidgetListener<T> =
void Function(BuildContext context, T previous, T current);